========
Get Help
========

We welcome usage questions and bug reports from all usres, even those who are new to
using the project.
There are a few things you can do to improve the likelihood of quickly getting a
good answer.

1. **Ask question in the right place**: We strongly prefer the use of
   `GitLab issues <https://gitlab.com/esa/pyxel/-/issues>`_.
   If you think you have found a bug then use GitLab.
2. **Create a minimal example**: It is ideal to create
   `minimal, complete, verifiable examples <https://stackoverflow.com/help/minimal-reproducible-example>`_.
   This significantly reduces the time that answerers spend understanding your situation,
   resulting in higher quality answers more quickly.
   See also `this blogpost <http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports>`_
   about crafting minimal bug reports.
   These have much higher likelihood of being answered.